# Petroleum, prices, and protests
# Espen Geelmuyden Rød
# Last update: Nov 1 2023

# Main analysis

rm(list = ls())

#library(readr)
library(ggplot2)
library(tidyverse)
library(dplyr)
library(stargazer)
#library(interplot)
#library(lubridate)
library(lfe)
library(foreign)

data <- read.csv("data.csv", na.strings = ".")
str(data)
names(data)
summary(data)

# Main analysis, all protest

m1 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m1)

m2 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct_sum3 + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m2)

m3 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct + price_usd_2015_growth_pct_sum3 + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m3)

library(stargazer)
stargazer(m1,m2,m3,
          title="Estimated effect of fuel price changes on protests.", align=TRUE, 
          dep.var.labels=c("Protest"),
          covariate.labels=c("Gasoline price growth 1m",
                             "Gasoline price growth 3m",
                             "Months since protest",
                             "Months since protest 2",
                             "Months since protest 3",
                             "Logged months since armed conflict",
                             "Crude oil price",
                             "Democracy",
                             "Democracy 2",
                             "GDP pc growth",
                             "Logged GDP pc",
                             "Logged population"),
          star.cutoffs=c(0.05,0.01), label = "", font.size="tiny", #, float.env = "sidewaystable",
          keep.stat=c("adj.rsq","n"),
          add.lines=list(c("Country SE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes"),
                         c("Country FE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes"), 
                         c("Year FE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes")),
          type="html",
          out="reg1.html")

# Main analysis, protest 1000

m1 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m1)

m2 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct_sum3 + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m2)

m3 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct + price_usd_2015_growth_pct_sum3 + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m3)

library(stargazer)
stargazer(m1,m2,m3,
          title="Estimated effect of fuel price changes on large protests.", align=TRUE, 
          dep.var.labels=c("Large protest"),
          covariate.labels=c("Gasoline price growth 1m",
                             "Gasoline price growth 3m",
                             "Months since large protest",
                             "Months since large protest 2",
                             "Months since large protest 3",
                             "Logged months since armed conflict",
                             "Crude oil price",
                             "Democracy",
                             "Democracy 2",
                             "GDP pc growth",
                             "Logged GDP pc",
                             "Logged population"),
          star.cutoffs=c(0.05,0.01), label = "", font.size="tiny", #, float.env = "sidewaystable",
          keep.stat=c("adj.rsq","n"),
          add.lines=list(c("Country SE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes"),
                         c("Country FE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes"), 
                         c("Year FE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes")),
          type="html",
          out="reg2.html")




# Main analysis, all protest, control for inflation (annual)

m1 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + FP.CPI.TOTL.ZG_tlag1 + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m1)

m2 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct_sum3 + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + FP.CPI.TOTL.ZG_tlag1 + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m2)

m3 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct + price_usd_2015_growth_pct_sum3 + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + FP.CPI.TOTL.ZG_tlag1 + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m3)


library(stargazer)
stargazer(m1,m2,m3,
          title="Estimated effect of fuel price changes on protests.", align=TRUE, 
          dep.var.labels=c("Protest"),
          covariate.labels=c("Gasoline price growth 1m",
                             "Gasoline price growth 3m",
                             "Months since large protest",
                             "Months since large protest 2",
                             "Months since large protest 3",
                             "Logged months since armed conflict",
                             "Crude oil price",
                             "Democracy",
                             "Democracy 2",
                             "Inflation",
                             "GDP pc growth",
                             "Logged GDP pc",
                             "Logged population"),
          star.cutoffs=c(0.05,0.01), label = "", font.size="tiny", #, float.env = "sidewaystable",
          keep.stat=c("adj.rsq","n"),
          add.lines=list(c("Country SE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes"),
                         c("Country FE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes"), 
                         c("Year FE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes")),
          type="html",
          out="reg1_inflation_ctrl.html")

# Main analysis, protest 1000, control for inflation (annual)

m1 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + FP.CPI.TOTL.ZG_tlag1 + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m1)

m2 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct_sum3 + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + FP.CPI.TOTL.ZG_tlag1 + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m2)

m3 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct + price_usd_2015_growth_pct_sum3 + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + FP.CPI.TOTL.ZG_tlag1 + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m3)


library(stargazer)
stargazer(m1,m2,m3,
          title="Estimated effect of fuel price changes on large protests.", align=TRUE, 
          dep.var.labels=c("Large protest"),
          covariate.labels=c("Gasoline price growth 1m",
                             "Gasoline price growth 3m",
                             "Months since large protest",
                             "Months since large protest 2",
                             "Months since large protest 3",
                             "Logged months since armed conflict",
                             "Crude oil price",
                             "Democracy",
                             "Democracy 2",
                             "Inflation",
                             "GDP pc growth",
                             "Logged GDP pc",
                             "Logged population"),
          star.cutoffs=c(0.05,0.01), label = "", font.size="tiny", #, float.env = "sidewaystable",
          keep.stat=c("adj.rsq","n"),
          add.lines=list(c("Country SE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes"),
                         c("Country FE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes"), 
                         c("Year FE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes")),
          type="html",
          out="reg2_inflation_ctrl.html")








# Figures, linear and nonlinear effects
# 1 month effect

library(ggplot2)

summary(data$price_usd_2015_growth_pct)

gg1 <- ggplot(data[data$months_since_protest>2 & 
                     !is.na(data$price_usd_2015_growth_pct) & 
                     !is.na(data$price_usd_2015_growth_pct_sum3), ], 
              aes(x = price_usd_2015_growth_pct, y = protest_onset_2m)) +
  geom_smooth(method = "glm", se = TRUE, formula = "y ~ x", method.args = list(family = "binomial"(link = "logit")), color = "black") +
  xlab("Gasoline price growth 1m") + ylab("Pr(Protest)") +
  geom_hline(yintercept = 0, lty=2) + #geom_rug(sides="b") + expand_limits(y=c(0,.25)) +
  theme_bw() +
  geom_rug(sides="b") + coord_cartesian(ylim = c(0,0.5)) +
  theme(axis.text=element_text(size=14), axis.title=element_text(size=15,face="bold"))

print(gg1)

pdf("linear_effect_1month.pdf")
gg1
dev.off()


gg1 <- ggplot(data[data$months_since_protest>2 & 
                     !is.na(data$price_usd_2015_growth_pct) & 
                     !is.na(data$price_usd_2015_growth_pct_sum3), ], 
              aes(x = price_usd_2015_growth_pct, y = protest_onset_2m)) +
  geom_smooth(method = "glm", se = TRUE, formula = "y ~ poly(x,3,raw=T)", method.args = list(family = "binomial"(link = "logit")), color = "black") +
  xlab("Gasoline price growth 1m") + ylab("Pr(Protest)") +
  geom_hline(yintercept = 0, lty=2) + #geom_rug(sides="b") + expand_limits(y=c(0,.25)) +
  theme_bw() +
  geom_rug(sides="b") + coord_cartesian(ylim = c(0,0.5)) + #, xlim = c(-0.5851,2)) +
  theme(axis.text=element_text(size=14), axis.title=element_text(size=15,face="bold"))

print(gg1)

pdf("nonlinear_effect_1month.pdf")
gg1
dev.off()


# Figures, linear and nonlinear effects
# 3 month effect

gg1 <- ggplot(data[data$months_since_protest>2 & 
                     !is.na(data$price_usd_2015_growth_pct) & 
                     !is.na(data$price_usd_2015_growth_pct_sum3), ], 
              aes(x = price_usd_2015_growth_pct_sum3, y = protest_onset_2m)) +
  geom_smooth(method = "glm", se = TRUE, formula = "y ~ x", method.args = list(family = "binomial"(link = "logit")), color = "black") +
  xlab("Gasoline price growth 3m") + ylab("Pr(Protest)") +
  geom_hline(yintercept = 0, lty=2) + #geom_rug(sides="b") + expand_limits(y=c(0,.25)) +
  theme_bw() +
  geom_rug(sides="b") + coord_cartesian(ylim = c(0,0.5)) + #, xlim = c(-0.5851,2)) +
  theme(axis.text=element_text(size=14), axis.title=element_text(size=15,face="bold"))

print(gg1)

pdf("linear_effect_3month.pdf")
gg1
dev.off()

gg1 <- ggplot(data[data$months_since_protest>2 & 
                     !is.na(data$price_usd_2015_growth_pct) & 
                     !is.na(data$price_usd_2015_growth_pct_sum3), ], 
              aes(x = price_usd_2015_growth_pct_sum3, y = protest_onset_2m)) +
  geom_smooth(method = "glm", se = TRUE, formula = "y ~ poly(x,3,raw=T)", method.args = list(family = "binomial"(link = "logit")), color = "black") +
  xlab("Gasoline price growth 3m") + ylab("Pr(Protest)") +
  geom_hline(yintercept = 0, lty=2) + #geom_rug(sides="b") + expand_limits(y=c(0,.25)) +
  theme_bw() +
  geom_rug(sides="b") + coord_cartesian(ylim = c(0,0.5)) + #, xlim = c(-0.5851,2)) +
  theme(axis.text=element_text(size=14), axis.title=element_text(size=15,face="bold"))

print(gg1)

pdf("nonlinear_effect_3month.pdf")
gg1
dev.off()










# Oil producer dummy

summary(data$NY.GDP.PETR.RT.ZS_tlag1)
data$NY.GDP.PETR.RT.ZS_tlag1_dich <- NA
data$NY.GDP.PETR.RT.ZS_tlag1_dich[data$NY.GDP.PETR.RT.ZS_tlag1==0] <- 0
data$NY.GDP.PETR.RT.ZS_tlag1_dich[data$NY.GDP.PETR.RT.ZS_tlag1>0] <- 1
summary(data$NY.GDP.PETR.RT.ZS_tlag1_dich)
table(data$NY.GDP.PETR.RT.ZS_tlag1_dich)


# Main analysis, all protest, interactions

m1 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct*v2x_corr_tlag1 + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m1)

m2 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct_sum3*v2x_corr_tlag1 + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m2)


m3 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct*pctbmgap2015adj_tlag1 + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m3)

m4 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct_sum3*pctbmgap2015adj_tlag1 + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m4)

m5 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct*NY.GDP.PETR.RT.ZS_tlag1_dich + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m5)

m6 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct_sum3*NY.GDP.PETR.RT.ZS_tlag1_dich + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m6)


library(stargazer)
stargazer(m1,m2,m3,m4,m5,m6,
          title="Estimated effect of fuel price changes on protests.", align=TRUE, 
          dep.var.labels=c("Protest"),
          covariate.labels=c("Gasoline price growth 1m",
                             "Gasoline price growth 3m",
                             "Corruption",
                             "Net implicit tax (subsidy)",
                             "Oil producer",
                             "Months since large protest",
                             "Months since large protest 2",
                             "Months since large protest 3",
                             "Logged months since armed conflict",
                             "Crude oil price",
                             "Democracy",
                             "Democracy 2",
                             "Inflation",
                             "GDP pc growth",
                             "Logged GDP pc",
                             "Logged population",
                             "Gas. price gr. 1m * Corruption",
                             "Gas. price gr. 3m * Corruption",
                             "Gas. price gr. 1m * Net implicit tax",
                             "Gas. price gr. 3m * Net implicit tax",
                             "Gas. price gr. 1m * Oil producer",
                             "Gas. price gr. 3m * Oil producer"),
          star.cutoffs=c(0.05,0.01), label = "", font.size="tiny", #, float.env = "sidewaystable",
          keep.stat=c("adj.rsq","n"),
          add.lines=list(c("Country SE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes"),
                         c("Country FE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes"), 
                         c("Year FE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes")),
          type="html",
          out="reg3.html")

# Main analysis, protest 1000, interactions

m1 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct*v2x_corr_tlag1 + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m1)

m2 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct_sum3*v2x_corr_tlag1 + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m2)


m3 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct*pctbmgap2015adj_tlag1 + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m3)

m4 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct_sum3*pctbmgap2015adj_tlag1 + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m4)

m5 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct*NY.GDP.PETR.RT.ZS_tlag1_dich + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m5)

m6 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct_sum3*NY.GDP.PETR.RT.ZS_tlag1_dich + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m6)


library(stargazer)
stargazer(m1,m2,m3,m4,m5,m6,
          title="Estimated effect of fuel price changes on large protests.", align=TRUE, 
          dep.var.labels=c("Large protest"),
          covariate.labels=c("Gasoline price growth 1m",
                             "Gasoline price growth 3m",
                             "Corruption",
                             "Net implicit tax (subsidy)",
                             "Oil producer",
                             "Months since large protest",
                             "Months since large protest 2",
                             "Months since large protest 3",
                             "Logged months since armed conflict",
                             "Crude oil price",
                             "Democracy",
                             "Democracy 2",
                             "Inflation",
                             "GDP pc growth",
                             "Logged GDP pc",
                             "Logged population",
                             "Gas. price gr. 1m * Corruption",
                             "Gas. price gr. 3m * Corruption",
                             "Gas. price gr. 1m * Net implicit tax",
                             "Gas. price gr. 3m * Net implicit tax",
                             "Gas. price gr. 1m * Oil producer",
                             "Gas. price gr. 3m * Oil producer"),
          star.cutoffs=c(0.05,0.01), label = "", font.size="tiny", #, float.env = "sidewaystable",
          keep.stat=c("adj.rsq","n"),
          add.lines=list(c("Country SE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes"),
                         c("Country FE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes"), 
                         c("Year FE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes")),
          type="html",
          out="reg4.html")



# Main analysis, all protest, interactions

m1 <- felm(protest_onset_2m ~ benchmark_2015_adj_growth_pct*v2x_corr_tlag1 + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct) & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct_sum3), ])
summary(m1)

m2 <- felm(protest_onset_2m ~ benchmark_2015_adj_growth_pct_sum3*v2x_corr_tlag1 + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct) & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct_sum3), ])
summary(m2)


m3 <- felm(protest_onset_2m ~ benchmark_2015_adj_growth_pct*pctbmgap2015adj_tlag1 + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event + 
             poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct) & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct_sum3), ])
summary(m3)

m4 <- felm(protest_onset_2m ~ benchmark_2015_adj_growth_pct_sum3*pctbmgap2015adj_tlag1 + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct) & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct_sum3), ])
summary(m4)


m5 <- felm(protest_onset_2m ~ benchmark_2015_adj_growth_pct*NY.GDP.PETR.RT.ZS_tlag1_dich + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct) & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct_sum3), ])
summary(m5)

m6 <- felm(protest_onset_2m ~ benchmark_2015_adj_growth_pct_sum3*NY.GDP.PETR.RT.ZS_tlag1_dich + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct) & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct_sum3), ])
summary(m6)


library(stargazer)
stargazer(m1,m2,m3,m4,m5,m6,
          title="Estimated effect of fuel price changes on protests.", align=TRUE, 
          dep.var.labels=c("Protest"),
          covariate.labels=c("Gasoline benchmark price growth 1m",
                             "Gasoline benchmark price growth 3m",
                             "Corruption",
                             "Net implicit tax (subsidy)",
                             "Oil producer",
                             "Months since large protest",
                             "Months since large protest 2",
                             "Months since large protest 3",
                             "Logged months since armed conflict",
                             "Crude oil price",
                             "Democracy",
                             "Democracy 2",
                             "Inflation",
                             "GDP pc growth",
                             "Logged GDP pc",
                             "Logged population",
                             "Gas. benchm. price gr. 1m * Corruption",
                             "Gas. benchm. price gr. 3m * Corruption",
                             "Gas. benchm. price gr. 1m * Net implicit tax",
                             "Gas. benchm. price gr. 3m * Net implicit tax",
                             "Gas. benchm. price gr. 1m * Oil producer",
                             "Gas. benchm. price gr. 3m * Oil producer"),
          star.cutoffs=c(0.05,0.01), label = "", font.size="tiny", #, float.env = "sidewaystable",
          keep.stat=c("adj.rsq","n"),
          add.lines=list(c("Country SE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes"),
                         c("Country FE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes"), 
                         c("Year FE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes")),
          type="html",
          out="reg3_benchmark.html")

# Main analysis, protest 1000, interactions

m1 <- felm(protest1000_onset_2m ~ benchmark_2015_adj_growth_pct*v2x_corr_tlag1 + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct) & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct_sum3), ])
summary(m1)

m2 <- felm(protest1000_onset_2m ~ benchmark_2015_adj_growth_pct_sum3*v2x_corr_tlag1 + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct) & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct_sum3), ])
summary(m2)


m3 <- felm(protest1000_onset_2m ~ benchmark_2015_adj_growth_pct*pctbmgap2015adj_tlag1 + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct) & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct_sum3), ])
summary(m3)

m4 <- felm(protest1000_onset_2m ~ benchmark_2015_adj_growth_pct_sum3*pctbmgap2015adj_tlag1 + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct) & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct_sum3), ])
summary(m4)

m5 <- felm(protest1000_onset_2m ~ benchmark_2015_adj_growth_pct*NY.GDP.PETR.RT.ZS_tlag1 + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct) & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct_sum3), ])
summary(m5)

m6 <- felm(protest1000_onset_2m ~ benchmark_2015_adj_growth_pct_sum3*NY.GDP.PETR.RT.ZS_tlag1 + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct) & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct_sum3), ])
summary(m6)


library(stargazer)
stargazer(m1,m2,m3,m4,m5,m6,
          title="Estimated effect of fuel price changes on large protests.", align=TRUE, 
          dep.var.labels=c("Large protest"),
          covariate.labels=c("Gasoline benchmark price growth 1m",
                             "Gasoline benchmark price growth 3m",
                             "Corruption",
                             "Net implicit tax (subsidy)",
                             "Oil producer",
                             "Months since large protest",
                             "Months since large protest 2",
                             "Months since large protest 3",
                             "Logged months since armed conflict",
                             "Crude oil price",
                             "Democracy",
                             "Democracy 2",
                             "Inflation",
                             "GDP pc growth",
                             "Logged GDP pc",
                             "Logged population",
                             "Gas. benchm. price gr. 1m * Corruption",
                             "Gas. benchm. price gr. 3m * Corruption",
                             "Gas. benchm. price gr. 1m * Net implicit tax",
                             "Gas. benchm. price gr. 3m * Net implicit tax",
                             "Gas. benchm. price gr. 1m * Oil producer",
                             "Gas. benchm. price gr. 3m * Oil producer"),
          star.cutoffs=c(0.05,0.01), label = "", font.size="tiny", #, float.env = "sidewaystable",
          keep.stat=c("adj.rsq","n"),
          add.lines=list(c("Country SE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes"),
                         c("Country FE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes"), 
                         c("Year FE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes")),
          type="html",
          out="reg4_benchmark.html")


# Main analysis, all protest, polynomial interactions

m1 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct*poly(v2x_corr_tlag1,3,raw=T) + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m1)

m2 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct_sum3*poly(v2x_corr_tlag1,3,raw=T) + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m2)


m3 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct*poly(pctbmgap2015adj_tlag1,3,raw=T) + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m3)

m4 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct_sum3*poly(pctbmgap2015adj_tlag1,3,raw=T) + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m4)


library(stargazer)
stargazer(m1,m2,m3,m4,
          title="Estimated effect of fuel price changes on protests.", align=TRUE, 
          dep.var.labels=c("Protest"),
          covariate.labels=c("Gasoline price growth 1m",
                             "Gasoline price growth 3m",
                             "Corruption",
                             "Corruption 2",
                             "Corruption 3",
                             "Net implicit tax (subsidy)",
                             "Net implicit tax (subsidy) 2",
                             "Net implicit tax (subsidy) 3",
                             "Months since large protest",
                             "Months since large protest 2",
                             "Months since large protest 3",
                             "Logged months since armed conflict",
                             "Crude oil price",
                             "Democracy",
                             "Democracy 2",
                             "Inflation",
                             "GDP pc growth",
                             "Logged GDP pc",
                             "Logged population",
                             "Gas. price gr. 1m * Corruption",
                             "Gas. price gr. 1m * Corruption 2",
                             "Gas. price gr. 1m * Corruption 3",
                             "Gas. price gr. 3m * Corruption",
                             "Gas. price gr. 3m * Corruption 2",
                             "Gas. price gr. 3m * Corruption 3",
                             "Gas. price gr. 1m * Net implicit tax",
                             "Gas. price gr. 1m * Net implicit tax 2",
                             "Gas. price gr. 1m * Net implicit tax 3",
                             "Gas. price gr. 3m * Net implicit tax",
                             "Gas. price gr. 3m * Net implicit tax 2",
                             "Gas. price gr. 3m * Net implicit tax 3"),
          star.cutoffs=c(0.05,0.01), label = "", font.size="tiny", #, float.env = "sidewaystable",
          keep.stat=c("adj.rsq","n"),
          add.lines=list(c("Country SE", "Yes", "Yes", "Yes", "Yes"),
                         c("Country FE", "Yes", "Yes", "Yes", "Yes"), 
                         c("Year FE", "Yes", "Yes", "Yes", "Yes")),
          type="html",
          out="reg3_poly.html")

# Main analysis, protest 1000, polynomial interactions

m1 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct*poly(v2x_corr_tlag1,3,raw=T) + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m1)

m2 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct_sum3*poly(v2x_corr_tlag1,3,raw=T) + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m2)


m3 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct*poly(pctbmgap2015adj_tlag1,3,raw=T) + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m3)

m4 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct_sum3*poly(pctbmgap2015adj_tlag1,3,raw=T) + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m4)

library(stargazer)
stargazer(m1,m2,m3,m4,
          title="Estimated effect of fuel price changes on large protests.", align=TRUE, 
          dep.var.labels=c("Large protest"),
          covariate.labels=c("Gasoline price growth 1m",
                             "Gasoline price growth 3m",
                             "Corruption",
                             "Corruption 2",
                             "Corruption 3",
                             "Net implicit tax (subsidy)",
                             "Net implicit tax (subsidy) 2",
                             "Net implicit tax (subsidy) 3",
                             "Months since large protest",
                             "Months since large protest 2",
                             "Months since large protest 3",
                             "Logged months since armed conflict",
                             "Crude oil price",
                             "Democracy",
                             "Democracy 2",
                             "Inflation",
                             "GDP pc growth",
                             "Logged GDP pc",
                             "Logged population",
                             "Gas. price gr. 1m * Corruption",
                             "Gas. price gr. 1m * Corruption 2",
                             "Gas. price gr. 1m * Corruption 3",
                             "Gas. price gr. 3m * Corruption",
                             "Gas. price gr. 3m * Corruption 2",
                             "Gas. price gr. 3m * Corruption 3",
                             "Gas. price gr. 1m * Net implicit tax",
                             "Gas. price gr. 1m * Net implicit tax 2",
                             "Gas. price gr. 1m * Net implicit tax 3",
                             "Gas. price gr. 3m * Net implicit tax",
                             "Gas. price gr. 3m * Net implicit tax 2",
                             "Gas. price gr. 3m * Net implicit tax 3"),
          star.cutoffs=c(0.05,0.01), label = "", font.size="tiny", #, float.env = "sidewaystable",
          keep.stat=c("adj.rsq","n"),
          add.lines=list(c("Country SE", "Yes", "Yes", "Yes", "Yes"),
                         c("Country FE", "Yes", "Yes", "Yes", "Yes"), 
                         c("Year FE", "Yes", "Yes", "Yes", "Yes")),
          type="html",
          out="reg4_poly.html")



# Main analysis, all protest, polynomial interactions

m1 <- felm(protest_onset_2m ~ benchmark_2015_adj_growth_pct*poly(v2x_corr_tlag1,3,raw=T) + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct) & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct_sum3), ])
summary(m1)

m2 <- felm(protest_onset_2m ~ benchmark_2015_adj_growth_pct_sum3*poly(v2x_corr_tlag1,3,raw=T) + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct) & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct_sum3), ])
summary(m2)


m3 <- felm(protest_onset_2m ~ benchmark_2015_adj_growth_pct*poly(pctbmgap2015adj_tlag1,3,raw=T) + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event + 
             poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct) & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct_sum3), ])
summary(m3)

m4 <- felm(protest_onset_2m ~ benchmark_2015_adj_growth_pct_sum3*poly(pctbmgap2015adj_tlag1,3,raw=T) + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct) & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct_sum3), ])
summary(m4)


library(stargazer)
stargazer(m1,m2,m3,m4,
          title="Estimated effect of fuel price changes on protests.", align=TRUE, 
          dep.var.labels=c("Protest"),
          covariate.labels=c("Gasoline benchmark price growth 1m",
                             "Gasoline benchmark price growth 3m",
                             "Corruption",
                             "Corruption 2",
                             "Corruption 3",
                             "Net implicit tax (subsidy)",
                             "Net implicit tax (subsidy) 2",
                             "Net implicit tax (subsidy) 3",
                             "Months since large protest",
                             "Months since large protest 2",
                             "Months since large protest 3",
                             "Logged months since armed conflict",
                             "Crude oil price",
                             "Democracy",
                             "Democracy 2",
                             "Inflation",
                             "GDP pc growth",
                             "Logged GDP pc",
                             "Logged population",
                             "Gas. benchm. price gr.1m * Corruption",
                             "Gas. benchm. price gr.1m * Corruption 2",
                             "Gas. benchm. price gr.1m * Corruption 3",
                             "Gas. benchm. price gr.3m * Corruption",
                             "Gas. benchm. price gr.3m * Corruption 2",
                             "Gas. benchm. price gr.3m * Corruption 3",
                             "Gas. benchm. price gr.1m * Net implicit tax",
                             "Gas. benchm. price gr.1m * Net implicit tax 2",
                             "Gas. benchm. price gr.1m * Net implicit tax 3",
                             "Gas. benchm. price gr.3m * Net implicit tax",
                             "Gas. benchm. price gr.3m * Net implicit tax 2",
                             "Gas. benchm. price gr.3m * Net implicit tax 3"),
          star.cutoffs=c(0.05,0.01), label = "", font.size="tiny", #, float.env = "sidewaystable",
          keep.stat=c("adj.rsq","n"),
          add.lines=list(c("Country SE", "Yes", "Yes", "Yes", "Yes"),
                         c("Country FE", "Yes", "Yes", "Yes", "Yes"), 
                         c("Year FE", "Yes", "Yes", "Yes", "Yes")),
          type="html",
          out="reg3_poly_benchmark.html")

# Main analysis, protest 1000, polynomial interactions

m1 <- felm(protest1000_onset_2m ~ benchmark_2015_adj_growth_pct*poly(v2x_corr_tlag1,3,raw=T) + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct) & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct_sum3), ])
summary(m1)

m2 <- felm(protest1000_onset_2m ~ benchmark_2015_adj_growth_pct_sum3*poly(v2x_corr_tlag1,3,raw=T) + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct) & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct_sum3), ])
summary(m2)


m3 <- felm(protest1000_onset_2m ~ benchmark_2015_adj_growth_pct*poly(pctbmgap2015adj_tlag1,3,raw=T) + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct) & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct_sum3), ])
summary(m3)

m4 <- felm(protest1000_onset_2m ~ benchmark_2015_adj_growth_pct_sum3*poly(pctbmgap2015adj_tlag1,3,raw=T) + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct) & 
                                                 !is.na(data$benchmark_2015_adj_growth_pct_sum3), ])
summary(m4)


library(stargazer)
stargazer(m1,m2,m3,m4,
          title="Estimated effect of fuel price changes on large protests.", align=TRUE, 
          dep.var.labels=c("Large protest"),
          covariate.labels=c("Gasoline benchmark price growth 1m",
                             "Gasoline benchmark price growth 3m",
                             "Corruption",
                             "Corruption 2",
                             "Corruption 3",
                             "Net implicit tax (subsidy)",
                             "Net implicit tax (subsidy) 2",
                             "Net implicit tax (subsidy) 3",
                             "Months since large protest",
                             "Months since large protest 2",
                             "Months since large protest 3",
                             "Logged months since armed conflict",
                             "Crude oil price",
                             "Democracy",
                             "Democracy 2",
                             "Inflation",
                             "GDP pc growth",
                             "Logged GDP pc",
                             "Logged population",
                             "Gas. benchm. price gr.1m * Corruption",
                             "Gas. benchm. price gr.1m * Corruption 2",
                             "Gas. benchm. price gr.1m * Corruption 3",
                             "Gas. benchm. price gr.3m * Corruption",
                             "Gas. benchm. price gr.3m * Corruption 2",
                             "Gas. benchm. price gr.3m * Corruption 3",
                             "Gas. benchm. price gr.1m * Net implicit tax",
                             "Gas. benchm. price gr.1m * Net implicit tax 2",
                             "Gas. benchm. price gr.1m * Net implicit tax 3",
                             "Gas. benchm. price gr.3m * Net implicit tax",
                             "Gas. benchm. price gr.3m * Net implicit tax 2",
                             "Gas. benchm. price gr.3m * Net implicit tax 3"),
          star.cutoffs=c(0.05,0.01), label = "", font.size="tiny", #, float.env = "sidewaystable",
          keep.stat=c("adj.rsq","n"),
          add.lines=list(c("Country SE", "Yes", "Yes", "Yes", "Yes"),
                         c("Country FE", "Yes", "Yes", "Yes", "Yes"), 
                         c("Year FE", "Yes", "Yes", "Yes", "Yes")),
          type="html",
          out="reg4_poly_benchmark.html")
