# Petroleum, prices, and protests
# Espen Geelmuyden Rød
# Last update: Nov 1 2023

# Main analysis
# Cumulative effect over two months and six months

rm(list = ls())

#library(readr)
library(ggplot2)
library(tidyverse)
library(dplyr)
library(stargazer)
#library(interplot)
#library(lubridate)
library(lfe)
library(foreign)

data <- read.csv("data.csv", na.strings = ".")

str(data)
names(data)
summary(data)


# Creating cumulative variables

data <- data %>%
  unite(yearmonth, year, month, sep = '', remove = FALSE)

data$yearmonth <- as.numeric(data$yearmonth)
names(data)
library(runner)

data <- data %>%
  group_by(gwno) %>%
  arrange(gwno, yearmonth) %>%
  mutate(
    price_usd_2015_growth_usd_sum2 = sum_run(
      x = price_usd_2015_growth_usd, 
      k = 2, 
      lag = 0,
      idx = yearmonth),
    price_usd_2015_growth_usd_sum6 = sum_run(
      x = price_usd_2015_growth_usd, 
      k = 6, 
      lag = 0,
      idx = yearmonth),
    price_usd_2015_tlag2 = lag(price_usd_2015, 
                               n = 2),
    price_usd_2015_tlag6 = lag(price_usd_2015, 
                                n = 6)) %>%
  ungroup()

summary(data$price_usd_2015_growth_usd)
summary(data$price_usd_2015_growth_usd_sum2)

data$price_usd_2015_growth_pct_sum2 <- data$price_usd_2015_growth_usd_sum2 / data$price_usd_2015_tlag2
data$price_usd_2015_growth_pct_sum6 <- data$price_usd_2015_growth_usd_sum6 / data$price_usd_2015_tlag6

summary(data$price_usd_2015_growth_pct)
summary(data$price_usd_2015_growth_pct_sum2)
summary(data$price_usd_2015_growth_pct_sum3)
summary(data$price_usd_2015_growth_pct_sum6)



# Main analysis, all protest

m1 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct_sum2 + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m1)

m2 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct_sum6 + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m2)


library(stargazer)
stargazer(m1,m2,
          title="Estimated effect of fuel price changes on protests.", align=TRUE, 
          dep.var.labels=c("Protest"),
          covariate.labels=c("Gasoline price growth 2m",
                             "Gasoline price growth 6m",
                             "Months since protest",
                             "Months since protest 2",
                             "Months since protest 3",
                             "Logged months since armed conflict",
                             "Crude oil price",
                             "Democracy",
                             "Democracy 2",
                             "GDP pc growth",
                             "Logged GDP pc",
                             "Logged population"),
          star.cutoffs=c(0.05,0.01), label = "", font.size="tiny", #, float.env = "sidewaystable",
          keep.stat=c("adj.rsq","n"),
          add.lines=list(c("Country SE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes"),
                         c("Country FE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes"), 
                         c("Year FE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes")),
          type="html",
          out="reg1_2m6mcumulative.html")

# Main analysis, protest 1000

m1 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct_sum2 + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m1)

m2 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct_sum6 + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m2)


library(stargazer)
stargazer(m1,m2,
          title="Estimated effect of fuel price changes on large protests.", align=TRUE, 
          dep.var.labels=c("Large protest"),
          covariate.labels=c("Gasoline price growth 2m",
                             "Gasoline price growth 6m",
                             "Months since large protest",
                             "Months since large protest 2",
                             "Months since large protest 3",
                             "Logged months since armed conflict",
                             "Crude oil price",
                             "Democracy",
                             "Democracy 2",
                             "GDP pc growth",
                             "Logged GDP pc",
                             "Logged population"),
          star.cutoffs=c(0.05,0.01), label = "", font.size="tiny", #, float.env = "sidewaystable",
          keep.stat=c("adj.rsq","n"),
          add.lines=list(c("Country SE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes"),
                         c("Country FE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes"), 
                         c("Year FE", "Yes", "Yes", "Yes", "Yes", "Yes", "Yes")),
          type="html",
          out="reg2_2m6mcumulative.html")


