# Petroleum, prices, and protests
# Maps data
# Espen Geelmuyden Rød
# Last update: Nov 1 2023

rm(list = ls())

# Load libraries
library("tidyverse")
tidyverse_update()
library("cshapes")
library("tidyverse")
library("rgdal")
library("rgeos")
library("foreign")

# Using Global gasoline taxes and subsidies data (Ross et al 2017) as base
# Reading in data
data <- read.csv("data.csv", na = ".")
summary(data)
summary(data$bmgap2015adj)
summary(data$pctbmgap2015adj)

map_data <- data %>% 
  group_by(gwno) %>%
  summarise(
    protest = max(protest),
#    protest1000_weeks = sum(protest1000),
    protest1000 = max(protest1000),
    protestnr = sum(protestnr, na.rm = T),
    pctbmgap2015adj_mean = mean(pctbmgap2015adj, na.rm = T),
    pctbmgap2015adj_min = min(pctbmgap2015adj, na.rm = T),
    price_usd_2015_growth_pct_max = max(price_usd_2015_growth_pct, na.rm = T),
    price_usd_2015_growth_usd_max = max(price_usd_2015_growth_usd, na.rm = T),
    price_usd_2015_growth_pct_sum3_max = max(price_usd_2015_growth_pct_sum3, na.rm = T)) %>%
  ungroup()

map_data$price_usd_2015_growth_pct_max[is.infinite(map_data$price_usd_2015_growth_pct_max)] <- NA 
map_data$price_usd_2015_growth_usd_max[is.infinite(map_data$price_usd_2015_growth_usd_max)] <- NA 
map_data$pctbmgap2015adj_min[is.infinite(map_data$pctbmgap2015adj_min)] <- NA 
map_data$price_usd_2015_growth_pct_sum3_max[is.infinite(map_data$price_usd_2015_growth_pct_sum3_max)] <- NA 

summary(map_data)

# Retrieve the cshapes dataset
cshp.data <- cshp(date=as.Date("2015-6-30"), useGW=T)

# Get summary statistics
summary(cshp.data)

# Extract countries with protest data 2003-2010
#cows <- unique(mapdata$cowcode)
#mmadcountries <- cshp.data[cshp.data$cowcode %in% cows, ]
#table(mmadcountries$country_name[mmadcountries$cowcode==365])

# merge 
chsp.mapdata = left_join(cshp.data , map_data, by=c("gwcode"="gwno"))

#Maps

ggplot() +
  geom_sf(data = chsp.mapdata, aes(fill = log(protestnr+1))) + 
  scale_fill_viridis_c(option = "inferno", name = "Number of protests (logged)") +
  theme(panel.grid.major = element_blank(), 
        legend.position="bottom",
        plot.margin=unit(c(0.5,0.5,0.5,0.5),"cm"))

ggsave("protestnr_map.pdf", width = 6, height = 4)  

ggplot() +
  geom_sf(data = chsp.mapdata, aes(fill = pctbmgap2015adj_mean)) + 
  scale_fill_viridis_c(option = "inferno", name = "Net implicit tax (subsidy)") +
  theme(panel.grid.major = element_blank(), 
        legend.position="bottom",
        plot.margin=unit(c(0.5,0.5,0.5,0.5),"cm"))

ggsave("pctbmgap2015adj_mean_map.pdf", width = 6, height = 4)  


ggplot() +
  geom_sf(data = chsp.mapdata, aes(fill = log(price_usd_2015_growth_pct_max+1))) + 
  scale_fill_viridis_c(option = "inferno", name = "Gasoline price growth, 1 month (logged)") +
  theme(panel.grid.major = element_blank(), 
        legend.position="bottom",
        plot.margin=unit(c(0.5,0.5,0.5,0.5),"cm"))

ggsave("price_usd_2015_growth_pct_max_map.pdf", width = 6, height = 4)  

ggplot() +
  geom_sf(data = chsp.mapdata, aes(fill = log10(price_usd_2015_growth_pct_sum3_max+1))) + 
  scale_fill_viridis_c(option = "inferno", name = "Gasoline price growth, 3 months (logged)") +
  theme(panel.grid.major = element_blank(), 
        legend.position="bottom",
        plot.margin=unit(c(0.5,0.5,0.5,0.5),"cm"))

ggsave("price_usd_2015_growth_pct_sum3_max_map.pdf", width = 6, height = 4)  

