# Petroleum, prices, and protests
# Espen Geelmuyden Rød
# Last update: Nov 1 2022

# Simulation placebo

rm(list = ls())

#library(readr)
library(ggplot2)
library(tidyverse)
library(dplyr)
library(stargazer)
#library(interplot)
#library(lubridate)
library(lfe)
library(foreign)

data <- read.csv("data.csv", na.strings = ".")
str(data)

# Model

names(data)

m1 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m1)

###Create alternative protest variable `placebo': The variable shares the same amount of 0 and 1 of few and severe protests but the values are distributed randomly within units of gids and years.

sample <- data %>%
  group_by(gwno, year) %>%
  dplyr::select(date, 
                protest_onset_2m, 
                price_usd_2015_growth_pct,
                price_usd_2015_growth_pct_sum3,
                months_since_protest,
                lnmonths_since_ged_event,
                Crudeoilaverage_tlag1,
                v2x_polyarchy,
                NY.GDP.PCAP.CD_growth_pct,
                lnNY.GDP.PCAP.CD_tlag1,
                lnSP.POP.TOTL_tlag1)

###Setting seeds

seeds <- c(1:1000)

###Run Simulation of country, year and weekday FEs
coefs <- as.numeric(rep(NA, max(seeds))) ###create container to store results 

seed <- 1

for (seed in seeds) {
  print(seed)
  set.seed(seed)
  sample <- sample %>%
    group_by(gwno, year) %>%
    mutate(placebo_price_usd_2015_growth_pct = sample(price_usd_2015_growth_pct))
  
  model <- felm(protest_onset_2m ~ placebo_price_usd_2015_growth_pct + 
                  poly(months_since_protest,3,raw=T) + 
                  lnmonths_since_ged_event +
                  Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
                | gwno+year | 0 | gwno, data = sample[sample$months_since_protest>2 & 
                                                        !is.na(sample$price_usd_2015_growth_pct) & 
                                                        !is.na(sample$price_usd_2015_growth_pct_sum3), ])
  coefs[seed] <- coef(summary(model))["placebo_price_usd_2015_growth_pct","Estimate"]
  
}

quantile(coefs, c(.90, .95, .99)) # Estimate at 0.085 (95%) and 0.0111 (99%). Estimate for model is 0.102

d_coefs <- density(coefs) # returns the density data

pdf("placebo_simulation.pdf", height=4, width=4)
par(mar=c(4.5,4.5,1,1))
plot(d_coefs, main="", xlim=c(min(coefs), 0.15))
#abline(v=quantile(coef_ged_events, .95),col="red",lwd=2)
abline(v=1.024e-01,col="red",lwd=2)
dev.off()

save(coefs, file = "coefs_placebo01112023.rda")


load(file = "coefs_placebo01112023.rda")



# Checking that the random assignment works:

x <- subset(data, gwno==625 & year==2012, select = c(gwno, year, date, price_usd_2015_growth_usd))
x2 <- subset(sample, gwno==625 & year==2012, select = c(gwno, year, date, placebo_price_usd_2015_growth_usd))

