# Petroleum, prices, and protests
# Espen Geelmuyden Rød
# Last update: Nov 1 2023

# Main analysis

rm(list = ls())

#library(readr)
library(ggplot2)
library(tidyverse)
library(dplyr)
library(stargazer)
#library(interplot)
#library(lubridate)
library(lfe)
library(foreign)

data <- read.csv("data.csv", na.strings = ".")
str(data)
names(data)
summary(data)

# List of high price changes and protest

# 1 month

summary(data$price_usd_2015_growth_pct)

x <- data %>%
  filter(protest_onset_2m==1) %>%
  arrange(desc(price_usd_2015_growth_pct)) %>%
  slice(1:10) %>%
  select(country, year, month, 
         price_usd_2015_growth_pct, price_usd_2015_growth_pct_sum3,
         protest_onset_2m, protest1000_onset_2m,
         protesteridentity, protesterdemand1, protesterdemand2, protesterdemand3, protesterdemand4)

write.table(x, "cases_highpricechange1month_and_protest.csv", row.names=F, na = ".", sep = ";")

x2 <- data %>%
  arrange(desc(price_usd_2015_growth_pct)) %>%
  slice(1:10) %>%
  select(country, year, month, 
         price_usd_2015_growth_pct, price_usd_2015_growth_pct_sum3,
         protest_onset_2m, protest1000_onset_2m,
         protesteridentity, protesterdemand1, protesterdemand2, protesterdemand3, protesterdemand4)

write.table(x2, "cases_highpricechange1month.csv", row.names=F, na = ".",sep = ";")

# 3 month

summary(data$price_usd_2015_growth_pct)

x <- data %>%
  filter(protest_onset_2m==1) %>%
  arrange(desc(price_usd_2015_growth_pct_sum3)) %>%
  slice(1:10) %>%
  select(country, year, month, 
         price_usd_2015_growth_pct, price_usd_2015_growth_pct_sum3,
         protest_onset_2m, protest1000_onset_2m,
         protesteridentity, protesterdemand1, protesterdemand2, protesterdemand3, protesterdemand4)

write.table(x, "cases_highpricechange3month_and_protest.csv", row.names=F, na = ".", sep = ";")

x2 <- data %>%
  arrange(desc(price_usd_2015_growth_pct_sum3)) %>%
  slice(1:10) %>%
  select(country, year, month, 
         price_usd_2015_growth_pct, price_usd_2015_growth_pct_sum3,
         protest_onset_2m, protest1000_onset_2m,
         protesteridentity, protesterdemand1, protesterdemand2, protesterdemand3, protesterdemand4)

write.table(x2, "cases_highpricechange3month.csv", row.names=F, na = ".",sep = ";")


# 12 month

summary(data$price_usd_2015_growth_pct_sum12)

x <- data %>%
  filter(price_usd_2015_growth_pct_sum12>0.5 & protest_onset_2m==1) %>%
  select(country, year, month, 
         price_usd_2015_growth_pct, price_usd_2015_growth_pct_sum12,
         protest_onset_2m, protest1000_onset_2m,
         protesteridentity, protesterdemand1, protesterdemand2, protesterdemand3, protesterdemand4)

write.table(x, "cases_highpricechange12month_and_protest.csv", row.names=F, na = ".", sep = ";")

x2 <- data %>%
  filter(price_usd_2015_growth_pct_sum12>1) %>%
  select(country, year, month, 
         price_usd_2015_growth_pct, price_usd_2015_growth_pct_sum12,
         protest_onset_2m, protest1000_onset_2m,
         protesteridentity, protesterdemand1, protesterdemand2, protesterdemand3, protesterdemand4)

write.table(x2, "cases_highpricechange12month.csv", row.names=F, na = ".",sep = ";")


summary(data$price_usd_2015_growth_pct_sum3)

x2 <- data %>%
  filter(price_usd_2015_growth_pct_sum3>1) %>%
  select(country, year, month, 
         price_usd_2015_growth_pct, price_usd_2015_growth_pct_sum12,
         protest_onset_2m, protest1000_onset_2m,
         protesteridentity, protesterdemand1, protesterdemand2, protesterdemand3, protesterdemand4)

write.table(x2, "cases_highpricechange.csv", row.names=F, na = ".",sep = ";")
