# Petroleum, prices, and protests
# Espen Geelmuyden Rød
# Last update: Nov 1 2023

# Main analysis

rm(list = ls())

library(tidyverse)
library(vroom)

descriptives.data <- vroom("data.csv", na = ".",
                           col_select = c(c("protest_onset_2m", 
                                            "protest1000_onset_2m", 
                                            "price_usd_2015_growth_pct",
                                            "price_usd_2015_growth_pct_sum3",
                                            "months_since_protest",
                                            "lnmonths_since_ged_event",
                                            "Crudeoilaverage_tlag1",
                                            "v2x_polyarchy",
                                            "NY.GDP.PCAP.CD_growth_pct",
                                            "lnNY.GDP.PCAP.CD_tlag1",
                                            "lnSP.POP.TOTL_tlag1",
                                            "FP.CPI.TOTL.ZG_tlag1",
                                            "v2x_corr_tlag1",
                                            "pctbmgap2015adj_tlag1",
                                            "NY.GDP.PETR.RT.ZS_tlag1",
                                            "benchmark_2015_adj_growth_pct",
                                            "benchmark_2015_adj_growth_pct_sum3")
                                          )) %>% 
  filter(months_since_protest>2) 

# Oil producer dummy

summary(descriptives.data$NY.GDP.PETR.RT.ZS_tlag1)
descriptives.data$NY.GDP.PETR.RT.ZS_tlag1_dich <- NA
descriptives.data$NY.GDP.PETR.RT.ZS_tlag1_dich[descriptives.data$NY.GDP.PETR.RT.ZS_tlag1==0] <- 0
descriptives.data$NY.GDP.PETR.RT.ZS_tlag1_dich[descriptives.data$NY.GDP.PETR.RT.ZS_tlag1>0] <- 1
summary(descriptives.data$NY.GDP.PETR.RT.ZS_tlag1_dich)
table(descriptives.data$NY.GDP.PETR.RT.ZS_tlag1_dich)

# Summary stats table

library(stargazer)
stargazer(as.data.frame(descriptives.data), digits=2, summary.stat = c("n", "mean", "sd","min","max"),
          covariate.labels=c("Protest",
                             "Large protest",
                             "Gasoline price growth 1m",
                             "Gasoline price growth 3m",
                             "Months since large protest",
                             "Logged months since armed conflict",
                             "Crude oil price",
                             "Democracy",
                             "GDP pc growth",
                             "Logged GDP pc",
                             "Logged population",
                             "Inflation",
                             "Corruption",
                             "Net implicit tax (subsidy)",
                             "Oil production (percent of GDP)",
                             "Gasoline benchmark price growth 1m",
                             "Gasoline benchmark price growth 3m",
                             "Oil producer"), 
          type="html",
          title="Descriptive statistics", out="descriptives.html")
