# Petroleum, prices, and protests
# Espen Geelmuyden Rød
# Last update: Nov 1 2023

# Main analysis

rm(list = ls())

#library(readr)
library(ggplot2)
library(tidyverse)
library(dplyr)
library(stargazer)
#library(interplot)
#library(lubridate)
library(lfe)
library(foreign)
library(sandwich)
library(lmtest)

data <- read.csv("data.csv", na.strings = ".")
str(data)
names(data)
summary(data)

# Main analysis, all protest

m1 <- glm(protest_onset_2m ~ price_usd_2015_growth_pct + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1,
          family = binomial(link = "logit"), data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m1)
nobs(m1)

m1 <- coeftest(m1, vcov. = vcovCL(m1, cluster = data$gwno[data$months_since_protest>2 & 
                                                        !is.na(data$price_usd_2015_growth_pct) & 
                                                        !is.na(data$price_usd_2015_growth_pct_sum3)], type = "HC0"))

m2 <- glm(protest_onset_2m ~ price_usd_2015_growth_pct_sum3 + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1,
          family = binomial(link = "logit"), data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m2)
nobs(m2)

m2 <- coeftest(m2, vcov. = vcovCL(m2, cluster = data$gwno[data$months_since_protest>2 & 
                                                      !is.na(data$price_usd_2015_growth_pct) & 
                                                      !is.na(data$price_usd_2015_growth_pct_sum3)], type = "HC0"))

m3 <- glm(protest_onset_2m ~ price_usd_2015_growth_pct + price_usd_2015_growth_pct_sum3 + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1,
           family = binomial(link = "logit"), data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m3)
nobs(m3)
m3 <- coeftest(m3, vcov. = vcovCL(m3, cluster = data$gwno[data$months_since_protest>2 & 
                                                      !is.na(data$price_usd_2015_growth_pct) & 
                                                      !is.na(data$price_usd_2015_growth_pct_sum3)], type = "HC0"))


library(stargazer)
stargazer(m1,m2,m3,
          title="Estimated effect of fuel price changes on protests, logistic regression model.", align=TRUE, 
          dep.var.labels=c("Protest"),
          covariate.labels=c("Gasoline price growth 1m",
                             "Gasoline price growth 3m",
                             "Months since protest",
                             "Months since protest 2",
                             "Months since protest 3",
                             "Logged months since armed conflict",
                             "Crude oil price",
                             "Democracy",
                             "Democracy 2",
                             "GDP pc growth",
                             "Logged GDP pc",
                             "Logged population"),
          star.cutoffs=c(0.05,0.01), label = "", font.size="tiny", #, float.env = "sidewaystable",
          keep.stat=c("adj.rsq","n"),
          add.lines=list(c("Observations", "15395", "15395", "15395"),
                         c("Country SE", "Yes", "Yes", "Yes"),
                         c("Country FE", "No", "No", "No"), 
                         c("Year FE", "No", "No", "No")),
          type="html",
          out="reg1_logit.html")

# Main analysis, protest 1000

m1 <- glm(protest1000_onset_2m ~ price_usd_2015_growth_pct + 
            poly(months_since_protest1000,3,raw=T) + 
            lnmonths_since_ged_event +
            Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1,
          family = binomial(link = "logit"), data = data[data$months_since_protest1000>2 & 
                                                           !is.na(data$price_usd_2015_growth_pct) & 
                                                           !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m1)
nobs(m1)

m1 <- coeftest(m1, vcov. = vcovCL(m1, cluster = data$gwno[data$months_since_protest1000>2 & 
                                                      !is.na(data$price_usd_2015_growth_pct) & 
                                                      !is.na(data$price_usd_2015_growth_pct_sum3)], type = "HC0"))

m2 <- glm(protest1000_onset_2m ~ price_usd_2015_growth_pct_sum3 + 
            poly(months_since_protest1000,3,raw=T) + 
            lnmonths_since_ged_event +
            Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1,
          family = binomial(link = "logit"), data = data[data$months_since_protest1000>2 & 
                                                           !is.na(data$price_usd_2015_growth_pct) & 
                                                           !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m2)
nobs(m2)

m2 <- coeftest(m2, vcov. = vcovCL(m2, cluster = data$gwno[data$months_since_protest1000>2 & 
                                                      !is.na(data$price_usd_2015_growth_pct) & 
                                                      !is.na(data$price_usd_2015_growth_pct_sum3)], type = "HC0"))

m3 <- glm(protest1000_onset_2m ~ price_usd_2015_growth_pct + price_usd_2015_growth_pct_sum3 + 
            poly(months_since_protest1000,3,raw=T) + 
            lnmonths_since_ged_event +
            Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1,
          family = binomial(link = "logit"), data = data[data$months_since_protest1000>2 & 
                                                           !is.na(data$price_usd_2015_growth_pct) & 
                                                           !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m3)
nobs(m3)

m3 <- coeftest(m3, vcov. = vcovCL(m3, cluster = data$gwno[data$months_since_protest1000>2 & 
                                                      !is.na(data$price_usd_2015_growth_pct) & 
                                                      !is.na(data$price_usd_2015_growth_pct_sum3)], type = "HC0"))

library(stargazer)
stargazer(m1,m2,m3,
          title="Estimated effect of fuel price changes on large protests, logistic regression model.", align=TRUE, 
          dep.var.labels=c("Large protest"),
          covariate.labels=c("Gasoline price growth 1m",
                             "Gasoline price growth 3m",
                             "Months since large protest",
                             "Months since large protest 2",
                             "Months since large protest 3",
                             "Logged months since armed conflict",
                             "Crude oil price",
                             "Democracy",
                             "Democracy 2",
                             "GDP pc growth",
                             "Logged GDP pc",
                             "Logged population"),
          star.cutoffs=c(0.05,0.01), label = "", font.size="tiny", #, float.env = "sidewaystable",
          keep.stat=c("adj.rsq","n"),
          add.lines=list(c("Observations", "17765", "17765", "17765"),
                         c("Country SE", "Yes", "Yes", "Yes"),
                         c("Country FE", "No", "No", "No"), 
                         c("Year FE", "No", "No", "No")),
          type="html",
          out="reg2_logit.html")

