# Petroleum, prices, and protests
# Espen Geelmuyden Rød
# Last update: Nov 1 2023

# Main analysis

rm(list = ls())

#library(readr)
library(ggplot2)
library(tidyverse)
library(dplyr)
library(stargazer)
#library(interplot)
#library(lubridate)
library(lfe)
library(foreign)

data <- read.csv("data.csv", na.strings = ".")
str(data)
names(data)
summary(data)

# Jackknife - leaving single countries out of the regression
# M1, all protest

cows <- unique(data$gwno[data$months_since_protest>2 & 
                              !is.na(data$price_usd_2015_growth_pct) & 
                              !is.na(data$price_usd_2015_growth_pct_sum3)])
jack.reg <- matrix(data=NA,nrow=length(cows),ncol=6)
jack.reg[,1] <- unique(data$gwno[data$months_since_protest>2 & 
                                      !is.na(data$price_usd_2015_growth_pct) & 
                                      !is.na(data$price_usd_2015_growth_pct_sum3)])

i <- 1

for (c in jack.reg[,1]) {
  m1 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct + 
               poly(months_since_protest,3,raw=T) + 
               lnmonths_since_ged_event +
               Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
             | gwno+year | 0 | gwno, data = data[data$gwno!=c & 
                                                   data$months_since_protest>2 & 
                                                   !is.na(data$price_usd_2015_growth_pct) & 
                                                   !is.na(data$price_usd_2015_growth_pct_sum3), ])
  
  jack.reg[i,2] <- m1$beta[1,1]
  jack.reg[i,3] <- m1$se[1]
  ci <- confint(m1, "price_usd_2015_growth_pct")
  jack.reg[i,4] <- ci[1]
  jack.reg[i,5] <- ci[2]
  jack.reg[i,6] <- unique(data$country[data$gwno==c])
  
  i <- i + 1
}

jack.reg <- as.data.frame(jack.reg)
str(jack.reg)
jack.reg$V2 <- as.numeric(jack.reg$V2)
jack.reg$V3 <- as.numeric(jack.reg$V3)
jack.reg$V4 <- as.numeric(jack.reg$V4)
jack.reg$V5 <- as.numeric(jack.reg$V5)

ggplot(jack.reg, aes(y=V2, x=V6)) + geom_point() + 
  geom_errorbar(aes(ymin=V4, ymax=V5)) + coord_flip() + 
  xlab("Country excluded") + ylab("Coefficient")

ggsave("jackknife_m1.pdf",
       device="pdf",
       width = 15,
       height = 10)  

# Jackknife - leaving single countries out of the regression
# M2, all protest

cows <- unique(data$gwno[data$months_since_protest>2 & 
                           !is.na(data$price_usd_2015_growth_pct) & 
                           !is.na(data$price_usd_2015_growth_pct_sum3)])
jack.reg <- matrix(data=NA,nrow=length(cows),ncol=6)
jack.reg[,1] <- unique(data$gwno[data$months_since_protest>2 & 
                                   !is.na(data$price_usd_2015_growth_pct) & 
                                   !is.na(data$price_usd_2015_growth_pct_sum3)])

i <- 1

for (c in jack.reg[,1]) {
  m1 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct_sum3 + 
               poly(months_since_protest,3,raw=T) + 
               lnmonths_since_ged_event +
               Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
             | gwno+year | 0 | gwno, data = data[data$gwno!=c & 
                                                   data$months_since_protest>2 & 
                                                   !is.na(data$price_usd_2015_growth_pct) & 
                                                   !is.na(data$price_usd_2015_growth_pct_sum3), ])
  
  jack.reg[i,2] <- m1$beta[1,1]
  jack.reg[i,3] <- m1$se[1]
  ci <- confint(m1, "price_usd_2015_growth_pct_sum3")
  jack.reg[i,4] <- ci[1]
  jack.reg[i,5] <- ci[2]
  jack.reg[i,6] <- unique(data$country[data$gwno==c])
  
  i <- i + 1
}

jack.reg <- as.data.frame(jack.reg)
str(jack.reg)
jack.reg$V2 <- as.numeric(jack.reg$V2)
jack.reg$V3 <- as.numeric(jack.reg$V3)
jack.reg$V4 <- as.numeric(jack.reg$V4)
jack.reg$V5 <- as.numeric(jack.reg$V5)

ggplot(jack.reg, aes(y=V2, x=V6)) + geom_point() + 
  geom_errorbar(aes(ymin=V4, ymax=V5)) + coord_flip() + 
  xlab("Country excluded") + ylab("Coefficient")

ggsave("jackknife_m2.pdf",
       device="pdf",
       width = 15,
       height = 10)  


# Jackknife - leaving single countries out of the regression
# M1, large protest

cows <- unique(data$gwno[data$months_since_protest1000>2 & 
                           !is.na(data$price_usd_2015_growth_pct) & 
                           !is.na(data$price_usd_2015_growth_pct_sum3)])
jack.reg <- matrix(data=NA,nrow=length(cows),ncol=6)
jack.reg[,1] <- unique(data$gwno[data$months_since_protest1000>2 & 
                                   !is.na(data$price_usd_2015_growth_pct) & 
                                   !is.na(data$price_usd_2015_growth_pct_sum3)])

i <- 1

for (c in jack.reg[,1]) {
  m1 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct + 
               poly(months_since_protest1000,3,raw=T) + 
               lnmonths_since_ged_event +
               Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
             | gwno+year | 0 | gwno, data = data[data$gwno!=c & 
                                                   data$months_since_protest1000>2 & 
                                                   !is.na(data$price_usd_2015_growth_pct) & 
                                                   !is.na(data$price_usd_2015_growth_pct_sum3), ])
  
  jack.reg[i,2] <- m1$beta[1,1]
  jack.reg[i,3] <- m1$se[1]
  ci <- confint(m1, "price_usd_2015_growth_pct")
  jack.reg[i,4] <- ci[1]
  jack.reg[i,5] <- ci[2]
  jack.reg[i,6] <- unique(data$country[data$gwno==c])
  
  i <- i + 1
}

jack.reg <- as.data.frame(jack.reg)
str(jack.reg)
jack.reg$V2 <- as.numeric(jack.reg$V2)
jack.reg$V3 <- as.numeric(jack.reg$V3)
jack.reg$V4 <- as.numeric(jack.reg$V4)
jack.reg$V5 <- as.numeric(jack.reg$V5)

ggplot(jack.reg, aes(y=V2, x=V6)) + geom_point() + 
  geom_errorbar(aes(ymin=V4, ymax=V5)) + coord_flip() + 
  xlab("Country excluded") + ylab("Coefficient")

ggsave("jackknife_m1_protest1000.pdf",
       device="pdf",
       width = 15,
       height = 10)  

# Jackknife - leaving single countries out of the regression
# M2, all large protest

cows <- unique(data$gwno[data$months_since_protest1000>2 & 
                           !is.na(data$price_usd_2015_growth_pct) & 
                           !is.na(data$price_usd_2015_growth_pct_sum3)])
jack.reg <- matrix(data=NA,nrow=length(cows),ncol=6)
jack.reg[,1] <- unique(data$gwno[data$months_since_protest1000>2 & 
                                   !is.na(data$price_usd_2015_growth_pct) & 
                                   !is.na(data$price_usd_2015_growth_pct_sum3)])

i <- 1

for (c in jack.reg[,1]) {
  m1 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct_sum3 + 
               poly(months_since_protest1000,3,raw=T) + 
               lnmonths_since_ged_event +
               Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
             | gwno+year | 0 | gwno, data = data[data$gwno!=c & 
                                                   data$months_since_protest1000>2 & 
                                                   !is.na(data$price_usd_2015_growth_pct) & 
                                                   !is.na(data$price_usd_2015_growth_pct_sum3), ])
  
  jack.reg[i,2] <- m1$beta[1,1]
  jack.reg[i,3] <- m1$se[1]
  ci <- confint(m1, "price_usd_2015_growth_pct_sum3")
  jack.reg[i,4] <- ci[1]
  jack.reg[i,5] <- ci[2]
  jack.reg[i,6] <- unique(data$country[data$gwno==c])
  
  i <- i + 1
}

jack.reg <- as.data.frame(jack.reg)
str(jack.reg)
jack.reg$V2 <- as.numeric(jack.reg$V2)
jack.reg$V3 <- as.numeric(jack.reg$V3)
jack.reg$V4 <- as.numeric(jack.reg$V4)
jack.reg$V5 <- as.numeric(jack.reg$V5)

ggplot(jack.reg, aes(y=V2, x=V6)) + geom_point() + 
  geom_errorbar(aes(ymin=V4, ymax=V5)) + coord_flip() + 
  xlab("Country excluded") + ylab("Coefficient")

ggsave("jackknife_m2_protest1000.pdf",
       device="pdf",
       width = 15,
       height = 10)  


