# Petroleum, prices, and protests
# Espen Geelmuyden Rød
# Last update: March 9 2023

# Interaction plots, oil dummy

rm(list = ls())

#library(readr)
library(ggplot2)
library(tidyverse)
library(dplyr)
library(stargazer)
#library(interplot)
#library(lubridate)
library(lfe)
library(foreign)
library(MASS)


data <- read.csv("/Users/egr/Dropbox (Personal)/Fuelling conflict_VR/ISA papper/Data/data_for_analysis/data_6feb2023.csv", na.strings = ".")
str(data)
names(data)

# Oil producer dummy

summary(data$NY.GDP.PETR.RT.ZS_tlag1)
data$NY.GDP.PETR.RT.ZS_tlag1_dich <- NA
data$NY.GDP.PETR.RT.ZS_tlag1_dich[data$NY.GDP.PETR.RT.ZS_tlag1==0] <- 0
data$NY.GDP.PETR.RT.ZS_tlag1_dich[data$NY.GDP.PETR.RT.ZS_tlag1>0] <- 1
summary(data$NY.GDP.PETR.RT.ZS_tlag1_dich)
table(data$NY.GDP.PETR.RT.ZS_tlag1_dich)

# Oil producer

m5 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct*NY.GDP.PETR.RT.ZS_tlag1_dich + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m5)

library(MASS)

set.seed(1337)

beta <- m5$beta

covvar <- m5$clustervcv
coefs.sim <- mvrnorm(10000, beta, covvar)

# Setting values for IV

summary(data$price_usd_2015_growth_pct)
price_usd_2015_growth_pct <- 0
price_usd_2015_growth_pct_1 <- 0.05

# Setting values for moderator

summary(data$NY.GDP.PETR.RT.ZS_tlag1_dich)

modifier <- sort(unique(data$NY.GDP.PETR.RT.ZS_tlag1_dich))
modifier <- na.omit(modifier)

#bind them together in a matrix   

effects0 <- cbind(price_usd_2015_growth_pct,
                  modifier,
                  mean(data$months_since_protest, na.rm = T),
                  mean(data$months_since_protest^2, na.rm = T),
                  mean(data$months_since_protest^3, na.rm = T),
                  mean(data$lnmonths_since_ged_event, na.rm = T),
                  mean(data$Crudeoilaverage_tlag1, na.rm = T),
                  mean(data$v2x_polyarchy, na.rm = T),
                  mean(data$v2x_polyarchy^2, na.rm = T),
                  mean(data$NY.GDP.PCAP.CD_growth_pct, na.rm = T),
                  mean(data$lnNY.GDP.PCAP.CD_tlag1, na.rm = T),
                  mean(data$lnSP.POP.TOTL_tlag1, na.rm = T),
                  price_usd_2015_growth_pct*modifier)

effects1 <- cbind(price_usd_2015_growth_pct_1,
                  modifier,
                  mean(data$months_since_protest, na.rm = T),
                  mean(data$months_since_protest^2, na.rm = T),
                  mean(data$months_since_protest^3, na.rm = T),
                  mean(data$lnmonths_since_ged_event, na.rm = T),
                  mean(data$Crudeoilaverage_tlag1, na.rm = T),
                  mean(data$v2x_polyarchy, na.rm = T),
                  mean(data$v2x_polyarchy^2, na.rm = T),
                  mean(data$NY.GDP.PCAP.CD_growth_pct, na.rm = T),
                  mean(data$lnNY.GDP.PCAP.CD_tlag1, na.rm = T),
                  mean(data$lnSP.POP.TOTL_tlag1, na.rm = T),
                  price_usd_2015_growth_pct_1*modifier)

#multiply the effects matrix with the matrix of simulated coefficients to obtain marginal effects
results0 <- coefs.sim %*% t(effects0)
results1 <- coefs.sim %*% t(effects1)

#evaluate each marginal effect using inverse logit, to obtain predicted probabilities
#results0 <- apply(results0,1:2, function(x) invlogit(x))
#results1 <- apply(results1,1:2, function(x) invlogit(x))

# subtract the estimated probabilities from each other
results <- results1 - results0

# means and cis

x <- modifier

means <- apply(results,2,mean)
sdUpper <- apply(results,2,function(x) quantile(x, .975))
sdLower <- apply(results,2,function(x) quantile(x, .025))

means[1]
sdUpper[1]
sdLower[1]

means[2]
sdUpper[2]
sdLower[2]


#graph the results

dfplot <- data.frame(x, means, sdLower, sdUpper)
p <- ggplot(dfplot, aes(x=x, y=means, ymin=sdLower, ymax=sdUpper)) + 
  geom_line() +
  geom_ribbon(aes(ymin=sdLower,ymax=sdUpper),alpha=0.3) +
  theme_bw() + geom_rug(sides="b") +geom_hline(yintercept = 0, lty=2) + xlab('Oil producer') + ylab('Change in protest probability \n as fuel price increases \n 1 month') +
  theme(axis.text=element_text(size=14), axis.title=element_text(size=15,face="bold")) + scale_x_continuous(breaks = c(0,1), labels = c(0,1), limits=c(0,1))

p

ggsave("/Users/egr/Dropbox (Personal)/Fuelling conflict_VR/ISA papper/Figures_Espen/price1monthXoil_producer.pdf", width = 6, height = 4)


m6 <- felm(protest_onset_2m ~ price_usd_2015_growth_pct_sum3*NY.GDP.PETR.RT.ZS_tlag1_dich + 
             poly(months_since_protest,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m6)


library(MASS)

set.seed(1337)

beta <- m6$beta

covvar <- m6$clustervcv
coefs.sim <- mvrnorm(10000, beta, covvar)

# Setting values for IV

summary(data$price_usd_2015_growth_pct_sum3)
price_usd_2015_growth_pct <- 0
price_usd_2015_growth_pct_1 <- 0.05

# Setting values for moderator

summary(data$NY.GDP.PETR.RT.ZS_tlag1_dich)

modifier <- sort(unique(data$NY.GDP.PETR.RT.ZS_tlag1_dich))
modifier <- na.omit(modifier)

#bind them together in a matrix   

effects0 <- cbind(price_usd_2015_growth_pct,
                  modifier,
                  mean(data$months_since_protest, na.rm = T),
                  mean(data$months_since_protest^2, na.rm = T),
                  mean(data$months_since_protest^3, na.rm = T),
                  mean(data$lnmonths_since_ged_event, na.rm = T),
                  mean(data$Crudeoilaverage_tlag1, na.rm = T),
                  mean(data$v2x_polyarchy, na.rm = T),
                  mean(data$v2x_polyarchy^2, na.rm = T),
                  mean(data$NY.GDP.PCAP.CD_growth_pct, na.rm = T),
                  mean(data$lnNY.GDP.PCAP.CD_tlag1, na.rm = T),
                  mean(data$lnSP.POP.TOTL_tlag1, na.rm = T),
                  price_usd_2015_growth_pct*modifier)

effects1 <- cbind(price_usd_2015_growth_pct_1,
                  modifier,
                  mean(data$months_since_protest, na.rm = T),
                  mean(data$months_since_protest^2, na.rm = T),
                  mean(data$months_since_protest^3, na.rm = T),
                  mean(data$lnmonths_since_ged_event, na.rm = T),
                  mean(data$Crudeoilaverage_tlag1, na.rm = T),
                  mean(data$v2x_polyarchy, na.rm = T),
                  mean(data$v2x_polyarchy^2, na.rm = T),
                  mean(data$NY.GDP.PCAP.CD_growth_pct, na.rm = T),
                  mean(data$lnNY.GDP.PCAP.CD_tlag1, na.rm = T),
                  mean(data$lnSP.POP.TOTL_tlag1, na.rm = T),
                  price_usd_2015_growth_pct_1*modifier)

#multiply the effects matrix with the matrix of simulated coefficients to obtain marginal effects
results0 <- coefs.sim %*% t(effects0)
results1 <- coefs.sim %*% t(effects1)

#evaluate each marginal effect using inverse logit, to obtain predicted probabilities
#results0 <- apply(results0,1:2, function(x) invlogit(x))
#results1 <- apply(results1,1:2, function(x) invlogit(x))

# subtract the estimated probabilities from each other
results <- results1 - results0

# means and cis

x <- modifier

means <- apply(results,2,mean)
sdUpper <- apply(results,2,function(x) quantile(x, .975))
sdLower <- apply(results,2,function(x) quantile(x, .025))

means[1]
sdUpper[1]
sdLower[1]

means[2]
sdUpper[2]
sdLower[2]


#graph the results

dfplot <- data.frame(x, means, sdLower, sdUpper)
p <- ggplot(dfplot, aes(x=x, y=means, ymin=sdLower, ymax=sdUpper)) + 
  geom_line() +
  geom_ribbon(aes(ymin=sdLower,ymax=sdUpper),alpha=0.3) +
  theme_bw() + geom_rug(sides="b") +geom_hline(yintercept = 0, lty=2) + xlab('Oil producer') + ylab('Change in protest probability \n as fuel price increases \n 3 months') +
  theme(axis.text=element_text(size=14), axis.title=element_text(size=15,face="bold")) + scale_x_continuous(breaks = c(0,1), labels = c(0,1), limits=c(0,1))

p

ggsave("/Users/egr/Dropbox (Personal)/Fuelling conflict_VR/ISA papper/Figures_Espen/price3monthXoil_producer.pdf", width = 6, height = 4)


# Oil producer

m5 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct*NY.GDP.PETR.RT.ZS_tlag1_dich + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m5)

library(MASS)

set.seed(1337)

beta <- m5$beta

covvar <- m5$clustervcv
coefs.sim <- mvrnorm(10000, beta, covvar)

# Setting values for IV

summary(data$price_usd_2015_growth_pct)
price_usd_2015_growth_pct <- 0
price_usd_2015_growth_pct_1 <- 0.05

# Setting values for moderator

summary(data$NY.GDP.PETR.RT.ZS_tlag1_dich)

modifier <- sort(unique(data$NY.GDP.PETR.RT.ZS_tlag1_dich))
modifier <- na.omit(modifier)

#bind them together in a matrix   

effects0 <- cbind(price_usd_2015_growth_pct,
                  modifier,
                  mean(data$months_since_protest1000, na.rm = T),
                  mean(data$months_since_protest1000^2, na.rm = T),
                  mean(data$months_since_protest1000^3, na.rm = T),
                  mean(data$lnmonths_since_ged_event, na.rm = T),
                  mean(data$Crudeoilaverage_tlag1, na.rm = T),
                  mean(data$v2x_polyarchy, na.rm = T),
                  mean(data$v2x_polyarchy^2, na.rm = T),
                  mean(data$NY.GDP.PCAP.CD_growth_pct, na.rm = T),
                  mean(data$lnNY.GDP.PCAP.CD_tlag1, na.rm = T),
                  mean(data$lnSP.POP.TOTL_tlag1, na.rm = T),
                  price_usd_2015_growth_pct*modifier)

effects1 <- cbind(price_usd_2015_growth_pct_1,
                  modifier,
                  mean(data$months_since_protest1000, na.rm = T),
                  mean(data$months_since_protest1000^2, na.rm = T),
                  mean(data$months_since_protest1000^3, na.rm = T),
                  mean(data$lnmonths_since_ged_event, na.rm = T),
                  mean(data$Crudeoilaverage_tlag1, na.rm = T),
                  mean(data$v2x_polyarchy, na.rm = T),
                  mean(data$v2x_polyarchy^2, na.rm = T),
                  mean(data$NY.GDP.PCAP.CD_growth_pct, na.rm = T),
                  mean(data$lnNY.GDP.PCAP.CD_tlag1, na.rm = T),
                  mean(data$lnSP.POP.TOTL_tlag1, na.rm = T),
                  price_usd_2015_growth_pct_1*modifier)

#multiply the effects matrix with the matrix of simulated coefficients to obtain marginal effects
results0 <- coefs.sim %*% t(effects0)
results1 <- coefs.sim %*% t(effects1)

#evaluate each marginal effect using inverse logit, to obtain predicted probabilities
#results0 <- apply(results0,1:2, function(x) invlogit(x))
#results1 <- apply(results1,1:2, function(x) invlogit(x))

# subtract the estimated probabilities from each other
results <- results1 - results0

# means and cis

x <- modifier

means <- apply(results,2,mean)
sdUpper <- apply(results,2,function(x) quantile(x, .975))
sdLower <- apply(results,2,function(x) quantile(x, .025))

means[1]
sdUpper[1]
sdLower[1]

means[2]
sdUpper[2]
sdLower[2]


#graph the results

dfplot <- data.frame(x, means, sdLower, sdUpper)
p <- ggplot(dfplot, aes(x=x, y=means, ymin=sdLower, ymax=sdUpper)) + 
  geom_line() +
  geom_ribbon(aes(ymin=sdLower,ymax=sdUpper),alpha=0.3) +
  theme_bw() + geom_rug(sides="b") +geom_hline(yintercept = 0, lty=2) + xlab('Oil producer') + ylab('Change in large protest probability \n as fuel price increases \n 1 month') +
  theme(axis.text=element_text(size=14), axis.title=element_text(size=15,face="bold")) + scale_x_continuous(breaks = c(0,1), labels = c(0,1), limits=c(0,1))

p

ggsave("/Users/egr/Dropbox (Personal)/Fuelling conflict_VR/ISA papper/Figures_Espen/price1monthXoil_producer_protest1000.pdf", width = 6, height = 4)


m6 <- felm(protest1000_onset_2m ~ price_usd_2015_growth_pct_sum3*NY.GDP.PETR.RT.ZS_tlag1_dich + 
             poly(months_since_protest1000,3,raw=T) + 
             lnmonths_since_ged_event +
             Crudeoilaverage_tlag1 + poly(v2x_polyarchy,2,raw=T) + NY.GDP.PCAP.CD_growth_pct + lnNY.GDP.PCAP.CD_tlag1 + lnSP.POP.TOTL_tlag1
           | gwno+year | 0 | gwno, data = data[data$months_since_protest1000>2 & 
                                                 !is.na(data$price_usd_2015_growth_pct) & 
                                                 !is.na(data$price_usd_2015_growth_pct_sum3), ])
summary(m6)


library(MASS)

set.seed(1337)

beta <- m6$beta

covvar <- m6$clustervcv
coefs.sim <- mvrnorm(10000, beta, covvar)

# Setting values for IV

summary(data$price_usd_2015_growth_pct_sum3)
price_usd_2015_growth_pct <- 0
price_usd_2015_growth_pct_1 <- 0.05

# Setting values for moderator

summary(data$NY.GDP.PETR.RT.ZS_tlag1_dich)

modifier <- sort(unique(data$NY.GDP.PETR.RT.ZS_tlag1_dich))
modifier <- na.omit(modifier)

#bind them together in a matrix   

effects0 <- cbind(price_usd_2015_growth_pct,
                  modifier,
                  mean(data$months_since_protest1000, na.rm = T),
                  mean(data$months_since_protest1000^2, na.rm = T),
                  mean(data$months_since_protest1000^3, na.rm = T),
                  mean(data$lnmonths_since_ged_event, na.rm = T),
                  mean(data$Crudeoilaverage_tlag1, na.rm = T),
                  mean(data$v2x_polyarchy, na.rm = T),
                  mean(data$v2x_polyarchy^2, na.rm = T),
                  mean(data$NY.GDP.PCAP.CD_growth_pct, na.rm = T),
                  mean(data$lnNY.GDP.PCAP.CD_tlag1, na.rm = T),
                  mean(data$lnSP.POP.TOTL_tlag1, na.rm = T),
                  price_usd_2015_growth_pct*modifier)

effects1 <- cbind(price_usd_2015_growth_pct_1,
                  modifier,
                  mean(data$months_since_protest1000, na.rm = T),
                  mean(data$months_since_protest1000^2, na.rm = T),
                  mean(data$months_since_protest1000^3, na.rm = T),
                  mean(data$lnmonths_since_ged_event, na.rm = T),
                  mean(data$Crudeoilaverage_tlag1, na.rm = T),
                  mean(data$v2x_polyarchy, na.rm = T),
                  mean(data$v2x_polyarchy^2, na.rm = T),
                  mean(data$NY.GDP.PCAP.CD_growth_pct, na.rm = T),
                  mean(data$lnNY.GDP.PCAP.CD_tlag1, na.rm = T),
                  mean(data$lnSP.POP.TOTL_tlag1, na.rm = T),
                  price_usd_2015_growth_pct_1*modifier)

#multiply the effects matrix with the matrix of simulated coefficients to obtain marginal effects
results0 <- coefs.sim %*% t(effects0)
results1 <- coefs.sim %*% t(effects1)

#evaluate each marginal effect using inverse logit, to obtain predicted probabilities
#results0 <- apply(results0,1:2, function(x) invlogit(x))
#results1 <- apply(results1,1:2, function(x) invlogit(x))

# subtract the estimated probabilities from each other
results <- results1 - results0

# means and cis

x <- modifier

means <- apply(results,2,mean)
sdUpper <- apply(results,2,function(x) quantile(x, .975))
sdLower <- apply(results,2,function(x) quantile(x, .025))

means[1]
sdUpper[1]
sdLower[1]

means[2]
sdUpper[2]
sdLower[2]


#graph the results

dfplot <- data.frame(x, means, sdLower, sdUpper)
p <- ggplot(dfplot, aes(x=x, y=means, ymin=sdLower, ymax=sdUpper)) + 
  geom_line() +
  geom_ribbon(aes(ymin=sdLower,ymax=sdUpper),alpha=0.3) +
  theme_bw() + geom_rug(sides="b") +geom_hline(yintercept = 0, lty=2) + xlab('Oil producer') + ylab('Change in large protest probability \n as fuel price increases \n 3 months') +
  theme(axis.text=element_text(size=14), axis.title=element_text(size=15,face="bold")) + scale_x_continuous(breaks = c(0,1), labels = c(0,1), limits=c(0,1))

p

ggsave("/Users/egr/Dropbox (Personal)/Fuelling conflict_VR/ISA papper/Figures_Espen/price3monthXoil_producer_protest1000.pdf", width = 6, height = 4)

